@@ -2,7 +2,7 @@ from justllms.__version__ import __version__
 from justllms.core.client import Client
 from justllms.core.completion import Completion, CompletionResponse
 from justllms.core.models import Message, Role
-from justllms.exceptions import JustLLMsError, ProviderError, RouteError
+from justllms.exceptions import JustLLMsError, ProviderError
 
 JustLLM = Client
 
@@ -16,5 +16,4 @@ __all__ = [
     "Role",
     "JustLLMsError",
     "ProviderError",
-    "RouteError",
 ]
