@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Literal, Optional, Union, overload
 
 from justllms.core.base import BaseResponse
 from justllms.core.models import Choice, Message, Usage
@@ -6,6 +6,7 @@ from justllms.utils.validators import validate_messages
 
 if TYPE_CHECKING:
     from justllms.core.client import Client
+    from justllms.core.streaming import AsyncStreamResponse, FakeStreamResponse, SyncStreamResponse
 
 
 class CompletionResponse(BaseResponse):
@@ -74,14 +75,17 @@ class CompletionResponse(BaseResponse):
 
 
 class Completion:
-    """Simplified completion interface focused on intelligent routing."""
+    """Simplified completion interface with automatic fallbacks."""
 
     def __init__(self, client: "Client"):
         self.client = client
 
+    @overload
     def create(
         self,
         messages: Union[List[Dict[str, Any]], List[Message]],
+        *,
+        stream: Literal[False] = False,
         model: Optional[str] = None,
         provider: Optional[str] = None,
         temperature: Optional[float] = None,
@@ -98,14 +102,67 @@ class Completion:
         response_format: Optional[Dict[str, Any]] = None,
         seed: Optional[int] = None,
         user: Optional[str] = None,
+        timeout: Optional[float] = None,
         **kwargs: Any,
-    ) -> CompletionResponse:
-        """Create a completion with intelligent routing.
+    ) -> CompletionResponse: ...
+
+    @overload
+    def create(
+        self,
+        messages: Union[List[Dict[str, Any]], List[Message]],
+        *,
+        stream: Literal[True],
+        model: Optional[str] = None,
+        provider: Optional[str] = None,
+        temperature: Optional[float] = None,
+        top_p: Optional[float] = None,
+        top_k: Optional[int] = None,
+        max_tokens: Optional[int] = None,
+        stop: Optional[Union[str, List[str]]] = None,
+        n: Optional[int] = None,
+        presence_penalty: Optional[float] = None,
+        frequency_penalty: Optional[float] = None,
+        generation_config: Optional[Dict[str, Any]] = None,
+        tools: Optional[List[Dict[str, Any]]] = None,
+        tool_choice: Optional[Union[str, Dict[str, Any]]] = None,
+        response_format: Optional[Dict[str, Any]] = None,
+        seed: Optional[int] = None,
+        user: Optional[str] = None,
+        timeout: Optional[float] = None,
+        **kwargs: Any,
+    ) -> "Union[SyncStreamResponse, AsyncStreamResponse, FakeStreamResponse]": ...
+
+    def create(
+        self,
+        messages: Union[List[Dict[str, Any]], List[Message]],
+        *,
+        model: Optional[str] = None,
+        provider: Optional[str] = None,
+        stream: bool = False,
+        temperature: Optional[float] = None,
+        top_p: Optional[float] = None,
+        top_k: Optional[int] = None,
+        max_tokens: Optional[int] = None,
+        stop: Optional[Union[str, List[str]]] = None,
+        n: Optional[int] = None,
+        presence_penalty: Optional[float] = None,
+        frequency_penalty: Optional[float] = None,
+        generation_config: Optional[Dict[str, Any]] = None,
+        tools: Optional[List[Dict[str, Any]]] = None,
+        tool_choice: Optional[Union[str, Dict[str, Any]]] = None,
+        response_format: Optional[Dict[str, Any]] = None,
+        seed: Optional[int] = None,
+        user: Optional[str] = None,
+        timeout: Optional[float] = None,
+        **kwargs: Any,
+    ) -> "Union[CompletionResponse, SyncStreamResponse, AsyncStreamResponse, FakeStreamResponse]":
+        """Create a completion with automatic fallbacks.
 
         Args:
             messages: List of messages in the conversation.
-            model: Specific model to use (optional, will be routed automatically if not provided).
+            model: Specific model to use (optional, uses fallback or first available if not provided).
             provider: Specific provider to use (optional).
+            stream: If True, returns streaming response instead of CompletionResponse.
 
             Common generation parameters (normalized across providers):
                 temperature: Sampling temperature (0.0-2.0). Controls randomness.
@@ -130,6 +187,7 @@ class Completion:
                 response_format: Response format specification (OpenAI).
                 seed: Random seed for deterministic outputs (OpenAI).
                 user: End-user identifier.
+                timeout: Request timeout in seconds. If None, no timeout is enforced.
 
         Returns:
             CompletionResponse: The model's response.
@@ -164,6 +222,7 @@ class Completion:
             "messages": formatted_messages,
             "model": model,
             "provider": provider,
+            "stream": stream,
             "temperature": temperature,
             "top_p": top_p,
             "top_k": top_k,
@@ -178,10 +237,11 @@ class Completion:
             "response_format": response_format,
             "seed": seed,
             "user": user,
+            "timeout": timeout,
             **kwargs,
         }
 
-        # Filter out None values, but keep model=None for routing
-        params = {k: v for k, v in params.items() if v is not None or k == "model"}
+        # Filter out None values, but keep model=None for fallback selection and stream=False
+        params = {k: v for k, v in params.items() if v is not None or k in ("model", "stream")}
 
         return self.client._create_completion(**params)
